@@ -13,10 +13,12 @@
 // limitations under the License.
 
 use super::{CError, DBValue, Result, Trie, TrieHash, TrieIterator, TrieLayout};
-use hash_db::{Hasher, EMPTY_PREFIX, Prefix};
-use crate::triedb::TrieDB;
-use crate::node::{NodePlan, NodeHandle, OwnedNode};
-use crate::nibble::{NibbleSlice, NibbleVec, nibble_ops};
+use crate::{
+	nibble::{nibble_ops, NibbleSlice, NibbleVec},
+	node::{NodeHandle, NodePlan, OwnedNode},
+	triedb::TrieDB,
+};
+use hash_db::{Hasher, Prefix, EMPTY_PREFIX};
 
 use crate::rstd::{rc::Rc, vec::Vec};
 
@@ -42,13 +44,14 @@ impl<H: Hasher> Crumb<H> {
 	fn increment(&mut self) {
 		self.status = match (self.status, self.node.node_plan()) {
 			(Status::Entering, NodePlan::Extension { .. }) => Status::At,
-			(Status::Entering, NodePlan::Branch { .. })
-			| (Status::Entering, NodePlan::NibbledBranch { .. }) => Status::At,
-			(Status::At, NodePlan::Branch { .. })
-			| (Status::At, NodePlan::NibbledBranch { .. }) => Status::AtChild(0),
-			(Status::AtChild(x), NodePlan::Branch { .. })
-			| (Status::AtChild(x), NodePlan::NibbledBranch { .. })
-			if x < (nibble_ops::NIBBLE_LENGTH - 1) => Status::AtChild(x + 1),
+			(Status::Entering, NodePlan::Branch { .. }) |
+			(Status::Entering, NodePlan::NibbledBranch { .. }) => Status::At,
+			(Status::At, NodePlan::Branch { .. }) |
+			(Status::At, NodePlan::NibbledBranch { .. }) => Status::AtChild(0),
+			(Status::AtChild(x), NodePlan::Branch { .. }) |
+			(Status::AtChild(x), NodePlan::NibbledBranch { .. })
+				if x < (nibble_ops::NIBBLE_LENGTH - 1) =>
+				Status::AtChild(x + 1),
 			_ => Status::Exiting,
 		}
 	}
@@ -70,51 +73,32 @@ pub struct SuspendedTrieDBNodeIterator<L: TrieLayout> {
 
 impl<L: TrieLayout> SuspendedTrieDBNodeIterator<L> {
 	/// Restore iterator.
-	pub fn unsafe_restore<'a>(
-		self,
-		db: &'a TrieDB<'a, L>,
-	) -> TrieDBNodeIterator<'a, L> {
-		TrieDBNodeIterator {
-			db,
-			trail: self.trail,
-			key_nibbles: self.key_nibbles,
-		}
+	pub fn unsafe_restore<'a>(self, db: &'a TrieDB<'a, L>) -> TrieDBNodeIterator<'a, L> {
+		TrieDBNodeIterator { db, trail: self.trail, key_nibbles: self.key_nibbles }
 	}
 }
 
 impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 	/// Create a new iterator.
 	pub fn new(db: &'a TrieDB<L>) -> Result<TrieDBNodeIterator<'a, L>, TrieHash<L>, CError<L>> {
-		let mut r = TrieDBNodeIterator {
-			db,
-			trail: Vec::with_capacity(8),
-			key_nibbles: NibbleVec::new(),
-		};
-		let (root_node, root_hash) = db.get_raw_or_lookup(
-			*db.root(),
-			NodeHandle::Hash(db.root().as_ref()),
-			EMPTY_PREFIX
-		)?;
+		let mut r =
+			TrieDBNodeIterator { db, trail: Vec::with_capacity(8), key_nibbles: NibbleVec::new() };
+		let (root_node, root_hash) =
+			db.get_raw_or_lookup(*db.root(), NodeHandle::Hash(db.root().as_ref()), EMPTY_PREFIX)?;
 		r.descend(root_node, root_hash);
 		Ok(r)
 	}
 
 	/// Descend into a payload.
 	fn descend(&mut self, node: OwnedNode<DBValue>, node_hash: Option<TrieHash<L>>) {
-		self.trail.push(Crumb {
-			hash: node_hash,
-			status: Status::Entering,
-			node: Rc::new(node),
-		});
+		self.trail
+			.push(Crumb { hash: node_hash, status: Status::Entering, node: Rc::new(node) });
 	}
 
 	/// Suspend iterator. Warning this does not hold guaranties it can be restored later.
 	/// Restoring requires that trie backend does not change.
 	pub fn suspend(self) -> SuspendedTrieDBNodeIterator<L> {
-		SuspendedTrieDBNodeIterator {
-			trail: self.trail,
-			key_nibbles: self.key_nibbles,
-		}
+		SuspendedTrieDBNodeIterator { trail: self.trail, key_nibbles: self.key_nibbles }
 	}
 
 	/// Fetch value by hash at a current node height
@@ -132,10 +116,7 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 	/// share its prefix with the node.
 	/// This indicates if there is still nodes to iterate over in the case
 	/// where we limit iteration to 'key' as a prefix.
-	fn seek_prefix(
-		&mut self,
-		key: &[u8],
-	) -> Result<bool, TrieHash<L>, CError<L>> {
+	fn seek_prefix(&mut self, key: &[u8]) -> Result<bool, TrieHash<L>, CError<L>> {
 		self.trail.clear();
 		self.key_nibbles.clear();
 		let key = NibbleSlice::new(key);
@@ -143,18 +124,17 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 		let (mut node, mut node_hash) = self.db.get_raw_or_lookup(
 			<TrieHash<L>>::default(),
 			NodeHandle::Hash(self.db.root().as_ref()),
-			EMPTY_PREFIX
+			EMPTY_PREFIX,
 		)?;
 		let mut partial = key;
 		let mut full_key_nibbles = 0;
 		loop {
 			let (next_node, next_node_hash) = {
 				self.descend(node, node_hash);
-				let crumb = self.trail.last_mut()
-					.expect(
-						"descend_into_node pushes a crumb onto the trial; \
-						thus the trail is non-empty; qed"
-					);
+				let crumb = self.trail.last_mut().expect(
+					"descend_into_node pushes a crumb onto the trial; \
+						thus the trail is non-empty; qed",
+				);
 				let node_data = crumb.node.data();
 
 				match crumb.node.node_plan() {
@@ -162,9 +142,9 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 						let slice = partial_plan.build(node_data);
 						if slice < partial {
 							crumb.status = Status::Exiting;
-							return Ok(false);
+							return Ok(false)
 						}
-						return Ok(slice.starts_with(&partial));
+						return Ok(slice.starts_with(&partial))
 					},
 					NodePlan::Extension { partial: partial_plan, child } => {
 						let slice = partial_plan.build(node_data);
@@ -172,9 +152,9 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 							if slice < partial {
 								crumb.status = Status::Exiting;
 								self.key_nibbles.append_partial(slice.right());
-								return Ok(false);
+								return Ok(false)
 							}
-							return Ok(slice.starts_with(&partial));
+							return Ok(slice.starts_with(&partial))
 						}
 
 						full_key_nibbles += slice.len();
@@ -186,12 +166,12 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 						self.db.get_raw_or_lookup(
 							node_hash.unwrap_or_default(),
 							child.build(node_data),
-							prefix.left()
+							prefix.left(),
 						)?
 					},
 					NodePlan::Branch { value: _, children } => {
 						if partial.is_empty() {
-							return Ok(true);
+							return Ok(true)
 						}
 
 						let i = partial.at(0);
@@ -206,10 +186,10 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 							self.db.get_raw_or_lookup(
 								node_hash.unwrap_or_default(),
 								child.build(node_data),
-								prefix.left()
+								prefix.left(),
 							)?
 						} else {
-							return Ok(false);
+							return Ok(false)
 						}
 					},
 					NodePlan::NibbledBranch { partial: partial_plan, value: _, children } => {
@@ -219,16 +199,16 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 								crumb.status = Status::Exiting;
 								self.key_nibbles.append_partial(slice.right());
 								self.key_nibbles.push((nibble_ops::NIBBLE_LENGTH - 1) as u8);
-								return Ok(false);
+								return Ok(false)
 							}
-							return Ok(slice.starts_with(&partial));
+							return Ok(slice.starts_with(&partial))
 						}
 
 						full_key_nibbles += slice.len();
 						partial = partial.mid(slice.len());
 
 						if partial.is_empty() {
-							return Ok(true);
+							return Ok(true)
 						}
 
 						let i = partial.at(0);
@@ -244,18 +224,18 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 							self.db.get_raw_or_lookup(
 								node_hash.unwrap_or_default(),
 								child.build(node_data),
-								prefix.left()
+								prefix.left(),
 							)?
 						} else {
-							return Ok(false);
+							return Ok(false)
 						}
 					},
 					NodePlan::Empty => {
 						if !partial.is_empty() {
 							crumb.status = Status::Exiting;
-							return Ok(false);
+							return Ok(false)
 						}
-						return Ok(true);
+						return Ok(true)
 					},
 				}
 			};
@@ -282,7 +262,11 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 
 	/// Advance the iterator into a prefix, no value out of the prefix will be accessed
 	/// or returned after this operation.
-	pub fn prefix_then_seek(&mut self, prefix: &[u8], seek: &[u8]) -> Result<(), TrieHash<L>, CError<L>> {
+	pub fn prefix_then_seek(
+		&mut self,
+		prefix: &[u8],
+		seek: &[u8],
+	) -> Result<(), TrieHash<L>, CError<L>> {
 		if seek.starts_with(prefix) {
 			self.seek_prefix(seek)?;
 			let prefix_len = prefix.len() * crate::nibble::nibble_ops::NIBBLE_PER_BYTE;
@@ -307,7 +291,7 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 				}
 				if len > prefix_len {
 					self.trail = self.trail.split_off(i);
-					return Ok(());
+					return Ok(())
 				}
 			}
 		}
@@ -323,17 +307,14 @@ impl<'a, L: TrieLayout> TrieDBNodeIterator<'a, L> {
 }
 
 impl<'a, L: TrieLayout> TrieIterator<L> for TrieDBNodeIterator<'a, L> {
-	fn seek(
-		&mut self,
-		key: &[u8],
-	) -> Result<(), TrieHash<L>, CError<L>> {
-		self.seek_prefix(key)
-			.map(|_| ())
+	fn seek(&mut self, key: &[u8]) -> Result<(), TrieHash<L>, CError<L>> {
+		self.seek_prefix(key).map(|_| ())
 	}
 }
 
 impl<'a, L: TrieLayout> Iterator for TrieDBNodeIterator<'a, L> {
-	type Item = Result<(NibbleVec, Option<TrieHash<L>>, Rc<OwnedNode<DBValue>>), TrieHash<L>, CError<L>>;
+	type Item =
+		Result<(NibbleVec, Option<TrieHash<L>>, Rc<OwnedNode<DBValue>>), TrieHash<L>, CError<L>>;
 
 	fn next(&mut self) -> Option<Self::Item> {
 		enum IterStep<O, E> {
@@ -355,7 +336,9 @@ impl<'a, L: TrieLayout> Iterator for TrieDBNodeIterator<'a, L> {
 							NodePlan::Extension { partial, .. } => {
 								self.key_nibbles.drop_lasts(partial.len());
 							},
-							NodePlan::Branch { .. } => { self.key_nibbles.pop(); },
+							NodePlan::Branch { .. } => {
+								self.key_nibbles.pop();
+							},
 							NodePlan::NibbledBranch { partial, .. } => {
 								self.key_nibbles.drop_lasts(partial.len() + 1);
 							},
@@ -365,13 +348,11 @@ impl<'a, L: TrieLayout> Iterator for TrieDBNodeIterator<'a, L> {
 					(Status::At, NodePlan::Extension { partial: partial_plan, child }) => {
 						let partial = partial_plan.build(node_data);
 						self.key_nibbles.append_partial(partial.right());
-						IterStep::Descend::<TrieHash<L>, CError<L>>(
-							self.db.get_raw_or_lookup(
-								b.hash.unwrap_or_default(),
-								child.build(node_data),
-								self.key_nibbles.as_prefix()
-							)
-						)
+						IterStep::Descend::<TrieHash<L>, CError<L>>(self.db.get_raw_or_lookup(
+							b.hash.unwrap_or_default(),
+							child.build(node_data),
+							self.key_nibbles.as_prefix(),
+						))
 					},
 					(Status::At, NodePlan::Branch { .. }) => {
 						self.key_nibbles.push(0);
@@ -383,18 +364,16 @@ impl<'a, L: TrieLayout> Iterator for TrieDBNodeIterator<'a, L> {
 						self.key_nibbles.push(0);
 						IterStep::Continue
 					},
-					(Status::AtChild(i), NodePlan::Branch { children, .. })
-					| (Status::AtChild(i), NodePlan::NibbledBranch { children, .. }) => {
+					(Status::AtChild(i), NodePlan::Branch { children, .. }) |
+					(Status::AtChild(i), NodePlan::NibbledBranch { children, .. }) => {
 						if let Some(child) = &children[i] {
 							self.key_nibbles.pop();
 							self.key_nibbles.push(i as u8);
-							IterStep::Descend::<TrieHash<L>, CError<L>>(
-								self.db.get_raw_or_lookup(
-									b.hash.unwrap_or_default(),
-									child.build(node_data),
-									self.key_nibbles.as_prefix()
-								)
-							)
+							IterStep::Descend::<TrieHash<L>, CError<L>>(self.db.get_raw_or_lookup(
+								b.hash.unwrap_or_default(),
+								child.build(node_data),
+								self.key_nibbles.as_prefix(),
+							))
 						} else {
 							IterStep::Continue
 						}
@@ -408,28 +387,25 @@ impl<'a, L: TrieLayout> Iterator for TrieDBNodeIterator<'a, L> {
 
 			match iter_step {
 				IterStep::YieldNode => {
-					let crumb = self.trail.last_mut()
-						.expect(
-							"method would have exited at top of previous block if trial were empty;\
+					let crumb = self.trail.last_mut().expect(
+						"method would have exited at top of previous block if trial were empty;\
 							trial could not have been modified within the block since it was immutably borrowed;\
-							qed"
-						);
+							qed",
+					);
 					crumb.increment();
 					return Some(Ok((
 						self.key_nibbles.clone(),
 						crumb.hash.clone(),
-						crumb.node.clone()
-					)));
+						crumb.node.clone(),
+					)))
 				},
 				IterStep::PopTrail => {
-					self.trail.pop()
-						.expect(
-							"method would have exited at top of previous block if trial were empty;\
+					self.trail.pop().expect(
+						"method would have exited at top of previous block if trial were empty;\
 							trial could not have been modified within the block since it was immutably borrowed;\
-							qed"
-						);
-					self.trail.last_mut()?
-						.increment();
+							qed",
+					);
+					self.trail.last_mut()?.increment();
 				},
 				IterStep::Descend::<TrieHash<L>, CError<L>>(Ok((node, node_hash))) => {
 					self.descend(node, node_hash);
@@ -443,7 +419,7 @@ impl<'a, L: TrieLayout> Iterator for TrieDBNodeIterator<'a, L> {
 								qed"
 						)
 						.increment();
-					return Some(Err(err));
+					return Some(Err(err))
 				},
 				IterStep::Continue => {
 					self.trail.last_mut()
