@@ -14,12 +14,14 @@
 
 //! Trie lookup via HashDB.
 
+use super::{CError, DBValue, Query, Result, TrieError, TrieHash, TrieLayout};
+use crate::{
+	nibble::NibbleSlice,
+	node::{decode_hash, Node, NodeHandle, Value},
+	node_codec::NodeCodec,
+	rstd::boxed::Box,
+};
 use hash_db::{HashDBRef, Prefix};
-use crate::nibble::NibbleSlice;
-use crate::node::{Node, NodeHandle, decode_hash, Value};
-use crate::node_codec::NodeCodec;
-use crate::rstd::boxed::Box;
-use super::{DBValue, Result, TrieError, Query, TrieLayout, CError, TrieHash};
 
 /// Trie lookup helper object.
 pub struct Lookup<'a, L: TrieLayout, Q: Query<L::Hash>> {
@@ -36,10 +38,15 @@ where
 	L: TrieLayout,
 	Q: Query<L::Hash>,
 {
-	fn decode(mut self, v: Value, prefix: Prefix, depth: u32) -> Result<Q::Item, TrieHash<L>, CError<L>> {
+	fn decode(
+		mut self,
+		v: Value,
+		prefix: Prefix,
+		depth: u32,
+	) -> Result<Q::Item, TrieHash<L>, CError<L>> {
 		match v {
 			Value::Inline(value) => Ok(self.query.decode(value)),
-			Value::Node(_, Some(value)) =>	Ok(self.query.decode(value.as_slice())),
+			Value::Node(_, Some(value)) => Ok(self.query.decode(value.as_slice())),
 			Value::Node(hash, None) => {
 				let mut res = TrieHash::<L>::default();
 				res.as_mut().copy_from_slice(hash);
@@ -55,10 +62,7 @@ where
 
 	/// Look up the given key. If the value is found, it will be passed to the given
 	/// function to decode or copy.
-	pub fn look_up(
-		mut self,
-		key: NibbleSlice,
-	) -> Result<Option<Q::Item>, TrieHash<L>, CError<L>> {
+	pub fn look_up(mut self, key: NibbleSlice) -> Result<Option<Q::Item>, TrieHash<L>, CError<L>> {
 		let mut partial = key;
 		let mut key_nibbles = 0;
 
@@ -71,10 +75,11 @@ where
 			let hash = self.hash;
 			let node_data = match self.db.get(&hash, key.mid(key_nibbles).left()) {
 				Some(value) => value,
-				None => return Err(Box::new(match depth {
-					0 => TrieError::InvalidStateRoot(hash),
-					_ => TrieError::IncompleteDatabase(hash),
-				})),
+				None =>
+					return Err(Box::new(match depth {
+						0 => TrieError::InvalidStateRoot(hash),
+						_ => TrieError::IncompleteDatabase(hash),
+					})),
 			};
 
 			self.query.record(&hash, &node_data, depth);
@@ -85,40 +90,37 @@ where
 			loop {
 				let decoded = match L::Codec::decode(node_data) {
 					Ok(node) => node,
-					Err(e) => {
-						return Err(Box::new(TrieError::DecoderError(hash, e)))
-					}
+					Err(e) => return Err(Box::new(TrieError::DecoderError(hash, e))),
 				};
 				let next_node = match decoded {
-					Node::Leaf(slice, value) => {
+					Node::Leaf(slice, value) =>
 						return Ok(match slice == partial {
 							true => Some(self.decode(value, full_key, depth)?),
 							false => None,
-						})
-					}
-					Node::Extension(slice, item) => {
+						}),
+					Node::Extension(slice, item) =>
 						if partial.starts_with(&slice) {
 							partial = partial.mid(slice.len());
 							key_nibbles += slice.len();
 							item
 						} else {
 							return Ok(None)
-						}
-					}
-					Node::Branch(children, value) => match partial.is_empty() {
-						true => if let Some(value) = value {
-							return Ok(Some(self.decode(value, full_key, depth)?));
-						} else {
-							return Ok(None);
 						},
+					Node::Branch(children, value) => match partial.is_empty() {
+						true =>
+							if let Some(value) = value {
+								return Ok(Some(self.decode(value, full_key, depth)?))
+							} else {
+								return Ok(None)
+							},
 						false => match children[partial.at(0) as usize] {
 							Some(x) => {
 								partial = partial.mid(1);
 								key_nibbles += 1;
 								x
-							}
-							None => return Ok(None)
-						}
+							},
+							None => return Ok(None),
+						},
 					},
 					Node::NibbledBranch(slice, children, value) => {
 						if !partial.starts_with(&slice) {
@@ -126,19 +128,20 @@ where
 						}
 
 						match partial.len() == slice.len() {
-							true => if let Some(value) = value {
-								return Ok(Some(self.decode(value, full_key, depth)?));
-							} else {
-								return Ok(None);
-							},
+							true =>
+								if let Some(value) = value {
+									return Ok(Some(self.decode(value, full_key, depth)?))
+								} else {
+									return Ok(None)
+								},
 							false => match children[partial.at(slice.len()) as usize] {
 								Some(x) => {
 									partial = partial.mid(slice.len() + 1);
 									key_nibbles += slice.len() + 1;
 									x
-								}
-								None => return Ok(None)
-							}
+								},
+								None => return Ok(None),
+							},
 						}
 					},
 					Node::Empty => return Ok(None),
@@ -149,7 +152,7 @@ where
 					NodeHandle::Hash(data) => {
 						self.hash = decode_hash::<L::Hash>(data)
 							.ok_or_else(|| Box::new(TrieError::InvalidHash(hash, data.to_vec())))?;
-						break;
+						break
 					},
 					NodeHandle::Inline(data) => {
 						node_data = data;
