@@ -12,17 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-use hash_db::{HashDBRef, Prefix, EMPTY_PREFIX};
-use crate::nibble::NibbleSlice;
-use crate::iterator::TrieDBNodeIterator;
-use crate::rstd::boxed::Box;
-use crate::DBValue;
-use super::node::{NodeHandle, Node, Value, OwnedNode, decode_hash};
-use super::lookup::Lookup;
-use super::{Result, Trie, TrieItem, TrieKeyItem, TrieError, TrieIterator, Query,
-	TrieLayout, CError, TrieHash};
 #[cfg(feature = "std")]
 use super::nibble::NibbleVec;
+use super::{
+	lookup::Lookup,
+	node::{decode_hash, Node, NodeHandle, OwnedNode, Value},
+	CError, Query, Result, Trie, TrieError, TrieHash, TrieItem, TrieIterator, TrieKeyItem,
+	TrieLayout,
+};
+use crate::{iterator::TrieDBNodeIterator, nibble::NibbleSlice, rstd::boxed::Box, DBValue};
+use hash_db::{HashDBRef, Prefix, EMPTY_PREFIX};
 
 #[cfg(feature = "std")]
 use crate::rstd::{fmt, vec::Vec};
@@ -67,24 +66,21 @@ where
 	/// Returns an error if `root` does not exist
 	pub fn new(
 		db: &'db dyn HashDBRef<L::Hash, DBValue>,
-		root: &'db TrieHash<L>
+		root: &'db TrieHash<L>,
 	) -> Result<Self, TrieHash<L>, CError<L>> {
 		if !db.contains(root, EMPTY_PREFIX) {
 			Err(Box::new(TrieError::InvalidStateRoot(*root)))
 		} else {
-			Ok(TrieDB {db, root, hash_count: 0})
+			Ok(TrieDB { db, root, hash_count: 0 })
 		}
 	}
 
 	/// `new_with_layout`, but do not check root presence, if missing
 	/// this will fail at first node access.
-	pub fn new_unchecked(
-		db: &'db dyn HashDBRef<L::Hash, DBValue>,
-		root: &'db TrieHash<L>,
-	) -> Self {
-		TrieDB {db, root, hash_count: 0}
+	pub fn new_unchecked(db: &'db dyn HashDBRef<L::Hash, DBValue>, root: &'db TrieHash<L>) -> Self {
+		TrieDB { db, root, hash_count: 0 }
 	}
-	
+
 	/// Get the backing database.
 	pub fn db(&'db self) -> &'db dyn HashDBRef<L::Hash, DBValue> {
 		self.db
@@ -108,18 +104,16 @@ where
 			NodeHandle::Hash(data) => {
 				let node_hash = decode_hash::<L::Hash>(data)
 					.ok_or_else(|| Box::new(TrieError::InvalidHash(parent_hash, data.to_vec())))?;
-				let node_data = self.db
-					.get(&node_hash, partial_key)
-					.ok_or_else(|| {
-						if partial_key == EMPTY_PREFIX {
-							Box::new(TrieError::InvalidStateRoot(node_hash))
-						} else {
-							Box::new(TrieError::IncompleteDatabase(node_hash))
-						}
-					})?;
+				let node_data = self.db.get(&node_hash, partial_key).ok_or_else(|| {
+					if partial_key == EMPTY_PREFIX {
+						Box::new(TrieError::InvalidStateRoot(node_hash))
+					} else {
+						Box::new(TrieError::IncompleteDatabase(node_hash))
+					}
+				})?;
 
 				(Some(node_hash), node_data)
-			}
+			},
 			NodeHandle::Inline(data) => (None, data.to_vec()),
 		};
 		let owned_node = OwnedNode::new::<L::Codec>(node_data)
@@ -132,32 +126,35 @@ impl<'db, L> Trie<L> for TrieDB<'db, L>
 where
 	L: TrieLayout,
 {
-	fn root(&self) -> &TrieHash<L> { self.root }
+	fn root(&self) -> &TrieHash<L> {
+		self.root
+	}
 
 	fn get_with<'a, 'key, Q: Query<L::Hash>>(
 		&'a self,
 		key: &'key [u8],
 		query: Q,
 	) -> Result<Option<Q::Item>, TrieHash<L>, CError<L>>
-		where 'a: 'key,
+	where
+		'a: 'key,
 	{
-		Lookup::<L, Q> {
-			db: self.db,
-			query,
-			hash: *self.root,
-		}.look_up(NibbleSlice::new(key))
+		Lookup::<L, Q> { db: self.db, query, hash: *self.root }.look_up(NibbleSlice::new(key))
 	}
 
-	fn iter<'a>(&'a self)-> Result<
-		Box<dyn TrieIterator<L, Item=TrieItem<TrieHash<L>, CError<L>>> + 'a>,
+	fn iter<'a>(
+		&'a self,
+	) -> Result<
+		Box<dyn TrieIterator<L, Item = TrieItem<TrieHash<L>, CError<L>>> + 'a>,
 		TrieHash<L>,
 		CError<L>,
 	> {
 		TrieDBIterator::new(self).map(|iter| Box::new(iter) as Box<_>)
 	}
 
-	fn key_iter<'a>(&'a self)-> Result<
-		Box<dyn TrieIterator<L, Item=TrieKeyItem<TrieHash<L>, CError<L>>> + 'a>,
+	fn key_iter<'a>(
+		&'a self,
+	) -> Result<
+		Box<dyn TrieIterator<L, Item = TrieKeyItem<TrieHash<L>, CError<L>>> + 'a>,
 		TrieHash<L>,
 		CError<L>,
 	> {
@@ -165,8 +162,7 @@ where
 	}
 }
 
-
-#[cfg(feature="std")]
+#[cfg(feature = "std")]
 // This is for pretty debug output only
 struct TrieAwareDebugNode<'db, 'a, L>
 where
@@ -178,7 +174,7 @@ where
 	index: Option<u8>,
 }
 
-#[cfg(feature="std")]
+#[cfg(feature = "std")]
 impl<'db, 'a, L> fmt::Debug for TrieAwareDebugNode<'db, 'a, L>
 where
 	L: TrieLayout,
@@ -187,7 +183,7 @@ where
 		match self.trie.get_raw_or_lookup(
 			<TrieHash<L>>::default(),
 			self.node_key,
-			self.partial_key.as_prefix()
+			self.partial_key.as_prefix(),
 		) {
 			Ok((owned_node, _node_hash)) => match owned_node.node() {
 				Node::Leaf(slice, value) => {
@@ -195,8 +191,7 @@ where
 					if let Some(i) = self.index {
 						disp.field("index", &i);
 					}
-					disp.field("slice", &slice)
-						.field("value", &value);
+					disp.field("slice", &slice).field("value", &value);
 					disp.finish()
 				},
 				Node::Extension(slice, item) => {
@@ -204,25 +199,30 @@ where
 					if let Some(i) = self.index {
 						disp.field("index", &i);
 					}
-					disp.field("slice", &slice)
-						.field("item", &TrieAwareDebugNode {
+					disp.field("slice", &slice).field(
+						"item",
+						&TrieAwareDebugNode {
 							trie: self.trie,
 							node_key: item,
-							partial_key: self.partial_key
+							partial_key: self
+								.partial_key
 								.clone_append_optional_slice_and_nibble(Some(&slice), None),
 							index: None,
-						});
+						},
+					);
 					disp.finish()
 				},
 				Node::Branch(ref nodes, ref value) => {
-					let nodes: Vec<TrieAwareDebugNode<L>> = nodes.into_iter()
+					let nodes: Vec<TrieAwareDebugNode<L>> = nodes
+						.into_iter()
 						.enumerate()
 						.filter_map(|(i, n)| n.map(|n| (i, n)))
 						.map(|(i, n)| TrieAwareDebugNode {
 							trie: self.trie,
 							index: Some(i as u8),
 							node_key: n,
-							partial_key: self.partial_key
+							partial_key: self
+								.partial_key
 								.clone_append_optional_slice_and_nibble(None, Some(i as u8)),
 						})
 						.collect();
@@ -230,28 +230,29 @@ where
 					if let Some(i) = self.index {
 						disp.field("index", &i);
 					}
-					disp.field("nodes", &nodes)
-						.field("value", &value);
+					disp.field("nodes", &nodes).field("value", &value);
 					disp.finish()
 				},
 				Node::NibbledBranch(slice, nodes, value) => {
-					let nodes: Vec<TrieAwareDebugNode<L>> = nodes.iter()
+					let nodes: Vec<TrieAwareDebugNode<L>> = nodes
+						.iter()
 						.enumerate()
 						.filter_map(|(i, n)| n.map(|n| (i, n)))
 						.map(|(i, n)| TrieAwareDebugNode {
 							trie: self.trie,
 							index: Some(i as u8),
 							node_key: n,
-							partial_key: self.partial_key
-								.clone_append_optional_slice_and_nibble(Some(&slice), Some(i as u8)),
-						}).collect();
+							partial_key: self.partial_key.clone_append_optional_slice_and_nibble(
+								Some(&slice),
+								Some(i as u8),
+							),
+						})
+						.collect();
 					let mut disp = f.debug_struct("Node::NibbledBranch");
 					if let Some(i) = self.index {
 						disp.field("index", &i);
 					}
-					disp.field("slice", &slice)
-						.field("nodes", &nodes)
-						.field("value", &value);
+					disp.field("slice", &slice).field("nodes", &nodes).field("value", &value);
 					disp.finish()
 				},
 				Node::Empty => {
@@ -259,7 +260,8 @@ where
 					disp.finish()
 				},
 			},
-			Err(e) => f.debug_struct("BROKEN_NODE")
+			Err(e) => f
+				.debug_struct("BROKEN_NODE")
 				.field("index", &self.index)
 				.field("key", &self.node_key)
 				.field("error", &format!("ERROR fetching node: {}", e))
@@ -268,7 +270,7 @@ where
 	}
 }
 
-#[cfg(feature="std")]
+#[cfg(feature = "std")]
 impl<'db, L> fmt::Debug for TrieDB<'db, L>
 where
 	L: TrieLayout,
@@ -276,12 +278,15 @@ where
 	fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
 		f.debug_struct("TrieDB")
 			.field("hash_count", &self.hash_count)
-			.field("root", &TrieAwareDebugNode {
-				trie: self,
-				node_key: NodeHandle::Hash(self.root().as_ref()),
-				partial_key: NibbleVec::new(),
-				index: None,
-			})
+			.field(
+				"root",
+				&TrieAwareDebugNode {
+					trie: self,
+					node_key: NodeHandle::Hash(self.root().as_ref()),
+					partial_key: NibbleVec::new(),
+					index: None,
+				},
+			)
 			.finish()
 	}
 }
@@ -304,13 +309,8 @@ pub struct SuspendedTrieDBKeyIterator<L: TrieLayout> {
 
 impl<L: TrieLayout> SuspendedTrieDBKeyIterator<L> {
 	/// Restore iterator.
-	pub fn unsafe_restore<'a>(
-		self,
-		db: &'a TrieDB<'a, L>,
-	) -> TrieDBKeyIterator<'a, L> {
-		TrieDBKeyIterator {
-			inner: self.inner.unsafe_restore(db),
-		}
+	pub fn unsafe_restore<'a>(self, db: &'a TrieDB<'a, L>) -> TrieDBKeyIterator<'a, L> {
+		TrieDBKeyIterator { inner: self.inner.unsafe_restore(db) }
 	}
 }
 
@@ -322,13 +322,14 @@ impl<'a, L: TrieLayout> TrieDBIterator<'a, L> {
 	}
 
 	/// Create a new iterator, but limited to a given prefix.
-	pub fn new_prefixed(db: &'a TrieDB<L>, prefix: &[u8]) -> Result<TrieDBIterator<'a, L>, TrieHash<L>, CError<L>> {
+	pub fn new_prefixed(
+		db: &'a TrieDB<L>,
+		prefix: &[u8],
+	) -> Result<TrieDBIterator<'a, L>, TrieHash<L>, CError<L>> {
 		let mut inner = TrieDBNodeIterator::new(db)?;
 		inner.prefix(prefix)?;
 
-		Ok(TrieDBIterator {
-			inner,
-		})
+		Ok(TrieDBIterator { inner })
 	}
 
 	/// Create a new iterator, but limited to a given prefix.
@@ -342,9 +343,7 @@ impl<'a, L: TrieLayout> TrieDBIterator<'a, L> {
 		let mut inner = TrieDBNodeIterator::new(db)?;
 		inner.prefix_then_seek(prefix, start_at)?;
 
-		Ok(TrieDBIterator {
-			inner,
-		})
+		Ok(TrieDBIterator { inner })
 	}
 }
 
@@ -365,19 +364,18 @@ impl<'a, L: TrieLayout> TrieDBKeyIterator<'a, L> {
 	/// Suspend iterator. Warning this does not hold guaranties it can be restore later.
 	/// Restoring require that trie backend did not change.
 	pub fn suspend(self) -> SuspendedTrieDBKeyIterator<L> {
-		SuspendedTrieDBKeyIterator {
-			inner: self.inner.suspend(),
-		}
+		SuspendedTrieDBKeyIterator { inner: self.inner.suspend() }
 	}
 
 	/// Create a new iterator, but limited to a given prefix.
-	pub fn new_prefixed(db: &'a TrieDB<L>, prefix: &[u8]) -> Result<TrieDBKeyIterator<'a, L>, TrieHash<L>, CError<L>> {
+	pub fn new_prefixed(
+		db: &'a TrieDB<L>,
+		prefix: &[u8],
+	) -> Result<TrieDBKeyIterator<'a, L>, TrieHash<L>, CError<L>> {
 		let mut inner = TrieDBNodeIterator::new(db)?;
 		inner.prefix(prefix)?;
 
-		Ok(TrieDBKeyIterator {
-			inner,
-		})
+		Ok(TrieDBKeyIterator { inner })
 	}
 
 	/// Create a new iterator, but limited to a given prefix.
@@ -391,9 +389,7 @@ impl<'a, L: TrieLayout> TrieDBKeyIterator<'a, L> {
 		let mut inner = TrieDBNodeIterator::new(db)?;
 		inner.prefix_then_seek(prefix, start_at)?;
 
-		Ok(TrieDBKeyIterator {
-			inner,
-		})
+		Ok(TrieDBKeyIterator { inner })
 	}
 }
 
@@ -415,40 +411,39 @@ impl<'a, L: TrieLayout> Iterator for TrieDBIterator<'a, L> {
 						Node::Leaf(partial, value) => {
 							prefix.append_partial(partial.right());
 							Some(value)
-						}
+						},
 						Node::Branch(_, value) => value,
 						Node::NibbledBranch(partial, _, value) => {
 							prefix.append_partial(partial.right());
 							value
-						}
+						},
 						_ => None,
 					};
 					if maybe_value.is_none() {
-						continue;
+						continue
 					}
 					let (key_slice, maybe_extra_nibble) = prefix.as_prefix();
 					let key = key_slice.to_vec();
 					if let Some(extra_nibble) = maybe_extra_nibble {
-						return Some(Err(Box::new(
-							TrieError::ValueAtIncompleteKey(key, extra_nibble)
-						)));
+						return Some(Err(Box::new(TrieError::ValueAtIncompleteKey(
+							key,
+							extra_nibble,
+						))))
 					}
 					let value = match maybe_value.expect("None checked above.") {
-						Value::Node(hash, None) =>  {
+						Value::Node(hash, None) => {
 							if let Some(value) = self.inner.fetch_value(&hash, (key_slice, None)) {
 								value
 							} else {
 								let mut res = TrieHash::<L>::default();
 								res.as_mut().copy_from_slice(hash);
-								return Some(Err(Box::new(
-									TrieError::IncompleteDatabase(res)
-								)));
+								return Some(Err(Box::new(TrieError::IncompleteDatabase(res))))
 							}
 						},
 						Value::Inline(value) => value.to_vec(),
 						Value::Node(_hash, Some(value)) => value,
 					};
-					return Some(Ok((key, value)));
+					return Some(Ok((key, value)))
 				},
 				Err(err) => return Some(Err(err)),
 			}
@@ -468,25 +463,26 @@ impl<'a, L: TrieLayout> Iterator for TrieDBKeyIterator<'a, L> {
 						Node::Leaf(partial, value) => {
 							prefix.append_partial(partial.right());
 							Some(value)
-						}
+						},
 						Node::Branch(_, value) => value,
 						Node::NibbledBranch(partial, _, value) => {
 							prefix.append_partial(partial.right());
 							value
-						}
+						},
 						_ => None,
 					};
 					if maybe_value.is_none() {
-						continue;
+						continue
 					} else {
 						let (key_slice, maybe_extra_nibble) = prefix.as_prefix();
 						let key = key_slice.to_vec();
 						if let Some(extra_nibble) = maybe_extra_nibble {
-							return Some(Err(Box::new(
-								TrieError::ValueAtIncompleteKey(key, extra_nibble)
-							)));
+							return Some(Err(Box::new(TrieError::ValueAtIncompleteKey(
+								key,
+								extra_nibble,
+							))))
 						}
-						return Some(Ok(key));
+						return Some(Ok(key))
 					}
 				},
 				Err(err) => return Some(Err(err)),
